import { useQuery } from "@tanstack/react-query";
import { Button } from "@/components/ui/button";
import { Card, CardContent } from "@/components/ui/card";
import { Skeleton } from "@/components/ui/skeleton";
import { fetchAffiliateProducts } from "@/lib/data";
import { trackAffiliateClick } from "@/lib/utils";

const AffiliateProducts = () => {
  const { data: products = [], isLoading } = useQuery({
    queryKey: ['/api/affiliate-products'],
    queryFn: fetchAffiliateProducts,
  });

  return (
    <section id="affiliations" className="py-12 bg-gray-50">
      <div className="container mx-auto px-4">
        <h2 className="text-2xl md:text-3xl font-bold mb-4">
          Produits d'affiliation recommandés
        </h2>
        <p className="text-gray-600 mb-8">
          Des produits soigneusement sélectionnés qui complètent parfaitement nos eBooks.
        </p>
        
        <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-6">
          {isLoading ? (
            Array(3).fill(0).map((_, i) => (
              <Card key={i} className="overflow-hidden">
                <div className="relative h-48">
                  <Skeleton className="w-full h-full" />
                </div>
                <CardContent className="p-4">
                  <Skeleton className="h-4 w-16 mb-1" />
                  <Skeleton className="h-6 w-full mb-2" />
                  <Skeleton className="h-4 w-full mb-4" />
                  <div className="flex justify-between items-center">
                    <Skeleton className="h-6 w-20" />
                    <Skeleton className="h-9 w-32" />
                  </div>
                </CardContent>
              </Card>
            ))
          ) : (
            products.map((product) => (
              <Card key={product.id} className="bg-white rounded-lg shadow-md overflow-hidden hover:shadow-lg transition-shadow duration-300">
                <div className="relative h-48">
                  <img 
                    src={product.imageUrl}
                    alt={product.title}
                    className="w-full h-full object-cover"
                  />
                  <div className="absolute top-0 right-0 bg-[#F59E0B] text-white text-xs px-2 py-1 m-2 rounded">
                    Partenaire
                  </div>
                </div>
                <CardContent className="p-4">
                  <div className="text-xs text-gray-500 mb-1">{product.category}</div>
                  <h3 className="font-semibold text-lg mb-2">{product.title}</h3>
                  <p className="text-gray-600 text-sm mb-4 line-clamp-3">
                    {product.description}
                  </p>
                  <div className="flex justify-between items-center">
                    <div>
                      {product.originalPrice && (
                        <span className="line-through text-gray-400 text-sm">{product.originalPrice}</span>
                      )}
                      <span className={`font-bold text-lg text-primary ${product.originalPrice ? 'ml-2' : ''}`}>
                        {product.price}
                      </span>
                    </div>
                    <Button 
                      className="bg-[#F59E0B] text-white hover:bg-[#F59E0B]/90 transition-colors duration-200"
                      onClick={() => trackAffiliateClick(product.externalUrl)}
                    >
                      En savoir plus
                    </Button>
                  </div>
                </CardContent>
              </Card>
            ))
          )}
        </div>
      </div>
    </section>
  );
};

export default AffiliateProducts;
