import { useQuery } from "@tanstack/react-query";
import { Skeleton } from "@/components/ui/skeleton";
import { Store } from "@/lib/icons";
import { type AffiliateProduct } from "@/lib/types";

const AffiliateProductCard = ({ product }: { product: AffiliateProduct }) => {
  return (
    <div className="bg-white rounded-xl shadow-md overflow-hidden transition-all hover:shadow-lg hover:scale-105">
      <div className="relative">
        <img 
          src={product.imageUrl} 
          alt={product.title} 
          className="w-full h-48 object-cover" 
        />
        <div className="absolute top-3 right-3 bg-teal-600 text-white text-sm font-medium py-1 px-2 rounded shadow-sm">
          Partenaire
        </div>
      </div>
      <div className="p-5">
        <h3 className="text-lg font-bold font-montserrat text-gray-900 mb-1">{product.title}</h3>
        <p className="text-sm text-gray-500 mb-3">{product.description}</p>
        <div className="flex justify-between items-center mb-4">
          <span className="text-[#f97316] font-bold">{product.price.toFixed(2)} €</span>
          <div className="flex items-center text-sm text-gray-600">
            <Store className="mr-1 h-4 w-4" /> {product.storeName}
          </div>
        </div>
        <a 
          href={product.storeUrl} 
          target="_blank" 
          rel="noopener noreferrer" 
          className="block w-full bg-teal-600 hover:bg-teal-700 text-white text-center font-medium py-2 rounded-lg transition shadow-sm"
        >
          Voir l'offre
        </a>
      </div>
    </div>
  );
};

const AffiliateProductSkeleton = () => (
  <div className="bg-white rounded-xl shadow-md overflow-hidden">
    <Skeleton className="h-48 w-full" />
    <div className="p-5">
      <Skeleton className="h-6 w-3/4 mb-1" />
      <Skeleton className="h-4 w-full mb-3" />
      <div className="flex justify-between items-center mb-4">
        <Skeleton className="h-5 w-16" />
        <Skeleton className="h-4 w-24" />
      </div>
      <Skeleton className="h-10 w-full" />
    </div>
  </div>
);

const AffiliateSection = () => {
  const { data: affiliateProducts, isLoading } = useQuery<AffiliateProduct[]>({
    queryKey: ['/api/affiliate-products'],
  });

  return (
    <section id="affiliate" className="py-16 bg-gray-50">
      <div className="container mx-auto px-4 sm:px-6 lg:px-8">
        <div className="text-center mb-12">
          <h2 className="text-3xl font-bold font-montserrat text-gray-900 mb-4">Produits Partenaires</h2>
          <p className="text-lg text-gray-600 max-w-2xl mx-auto">
            Découvrez ces produits sélectionnés avec soin pour compléter votre expérience
          </p>
        </div>

        <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-8">
          {isLoading ? (
            <>
              <AffiliateProductSkeleton />
              <AffiliateProductSkeleton />
              <AffiliateProductSkeleton />
            </>
          ) : (
            affiliateProducts?.map((product) => (
              <AffiliateProductCard key={product.id} product={product} />
            ))
          )}
        </div>
      </div>
    </section>
  );
};

export default AffiliateSection;
