import { Link } from "wouter";
import { useQuery } from "@tanstack/react-query";
import { Skeleton } from "@/components/ui/skeleton";
import { ArrowRight } from "lucide-react";
import { fetchCategories } from "@/lib/data";

const Categories = () => {
  const { data: categories = [], isLoading } = useQuery({
    queryKey: ['/api/categories'],
    queryFn: fetchCategories,
  });

  return (
    <section className="py-12 bg-gray-50">
      <div className="container mx-auto px-4">
        <h2 className="text-2xl md:text-3xl font-bold mb-8 text-center">
          Parcourez nos catégories
        </h2>
        
        <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-4 gap-6">
          {isLoading ? (
            Array(4).fill(0).map((_, i) => (
              <div key={i} className="bg-white rounded-lg shadow-md overflow-hidden h-full">
                <div className="relative h-40">
                  <Skeleton className="w-full h-full" />
                </div>
                <div className="p-4">
                  <Skeleton className="h-4 w-3/4 mb-2" />
                  <Skeleton className="h-4 w-full mb-4" />
                  <Skeleton className="h-4 w-1/2" />
                </div>
              </div>
            ))
          ) : (
            categories.map((category) => (
              <Link key={category.id} href={`/category/${category.name}`}>
                <a className="group">
                  <div className="bg-white rounded-lg shadow-md overflow-hidden hover:shadow-lg transition-shadow duration-300 h-full">
                    <div className="relative h-40">
                      <img 
                        src={category.imageUrl}
                        alt={category.name}
                        className="w-full h-full object-cover transition-transform duration-300 group-hover:scale-105"
                      />
                      <div className="absolute inset-0 bg-primary/50 flex items-center justify-center">
                        <h3 className="text-white text-xl font-semibold">{category.name}</h3>
                      </div>
                    </div>
                    <div className="p-4">
                      <p className="text-gray-600 text-sm">{category.description}</p>
                      <div className="mt-2 text-primary font-medium flex items-center group-hover:translate-x-1 transition-transform duration-200">
                        Voir les {category.itemCount} eBooks <ArrowRight className="ml-2 h-4 w-4" />
                      </div>
                    </div>
                  </div>
                </a>
              </Link>
            ))
          )}
        </div>
      </div>
    </section>
  );
};

export default Categories;
