import { Link } from "wouter";
import { Button } from "@/components/ui/button";

const HeroBanner = () => {
  return (
    <section className="relative bg-primary-900 text-white">
      <div className="absolute inset-0 bg-gradient-to-br from-primary-800 to-primary-950 opacity-90"></div>
      <div className="container relative mx-auto px-4 sm:px-6 lg:px-8 py-16 md:py-24">
        <div className="grid md:grid-cols-2 gap-8 items-center">
          <div className="space-y-6">
            <h1 className="text-3xl md:text-4xl lg:text-5xl font-bold font-montserrat leading-tight text-white drop-shadow-sm">
              Découvrez notre collection d'eBooks exclusifs
            </h1>
            <p className="text-lg md:text-xl text-white/90 drop-shadow-sm">
              Des guides professionnels aux romans captivants, enrichissez votre bibliothèque numérique avec KarukeraBiz.
            </p>
            <div className="flex flex-col sm:flex-row space-y-4 sm:space-y-0 sm:space-x-4 pt-4">
              <Button
                asChild
                className="bg-[#ff9633] hover:bg-[#f97316] text-white font-medium py-3 px-6 shadow-md"
                size="lg"
              >
                <a 
                  href="#bestsellers"
                  onClick={(e) => {
                    e.preventDefault();
                    document.getElementById('bestsellers')?.scrollIntoView({ behavior: 'smooth', block: 'start' });
                  }}
                >
                  Voir les meilleures ventes
                </a>
              </Button>
              <Button
                asChild
                variant="outline"
                className="bg-white/10 border-white text-white hover:bg-white/20 font-medium py-3 px-6 backdrop-blur-sm shadow-md"
                size="lg"
              >
                <a 
                  href="#categories"
                  onClick={(e) => {
                    e.preventDefault();
                    document.getElementById('categories')?.scrollIntoView({ behavior: 'smooth', block: 'start' });
                  }}
                >
                  Explorer les catégories
                </a>
              </Button>
            </div>
          </div>
          <div className="relative hidden md:block">
            <div className="absolute -left-4 top-4 w-48 h-64 bg-teal-500 rounded-lg shadow-lg transform -rotate-6 z-0"></div>
            <div className="absolute left-12 top-12 w-48 h-64 bg-[#f97316] rounded-lg shadow-lg transform rotate-3 z-10"></div>
            <div className="relative z-20 bg-white rounded-lg shadow-xl p-4 w-56 h-72 transform rotate-6 mx-auto">
              <img 
                src="https://images.unsplash.com/photo-1544947950-fa07a98d237f?ixlib=rb-4.0.3&auto=format&fit=crop&w=400&q=80" 
                alt="Ebook cover" 
                className="w-full h-full object-cover rounded" 
              />
            </div>
          </div>
        </div>
      </div>
      <div className="absolute bottom-0 left-0 right-0 h-16 bg-gradient-to-t from-gray-50 to-transparent"></div>
    </section>
  );
};

export default HeroBanner;
