import { 
  Product, 
  Category, 
  AffiliateProduct, 
  Testimonial 
} from "@shared/schema";
import { apiRequest } from "@/lib/queryClient";

export async function fetchFeaturedProducts(): Promise<Product[]> {
  const response = await fetch('/api/products/featured');
  if (!response.ok) {
    throw new Error('Failed to fetch featured products');
  }
  return response.json();
}

export async function fetchAllProducts(): Promise<Product[]> {
  const response = await fetch('/api/products');
  if (!response.ok) {
    throw new Error('Failed to fetch products');
  }
  return response.json();
}

export async function fetchProductsByCategory(category: string): Promise<Product[]> {
  const response = await fetch(`/api/products/category/${category}`);
  if (!response.ok) {
    throw new Error(`Failed to fetch products in category: ${category}`);
  }
  return response.json();
}

export async function fetchProduct(id: number): Promise<Product> {
  const response = await fetch(`/api/products/${id}`);
  if (!response.ok) {
    throw new Error(`Failed to fetch product with ID: ${id}`);
  }
  return response.json();
}

export async function fetchCategories(): Promise<Category[]> {
  const response = await fetch('/api/categories');
  if (!response.ok) {
    throw new Error('Failed to fetch categories');
  }
  return response.json();
}

export async function fetchAffiliateProducts(): Promise<AffiliateProduct[]> {
  const response = await fetch('/api/affiliate-products');
  if (!response.ok) {
    throw new Error('Failed to fetch affiliate products');
  }
  return response.json();
}

export async function fetchTestimonials(): Promise<Testimonial[]> {
  const response = await fetch('/api/testimonials');
  if (!response.ok) {
    throw new Error('Failed to fetch testimonials');
  }
  return response.json();
}

export async function submitContactForm(data: {
  name: string;
  email: string;
  subject: string;
  message: string;
}) {
  return apiRequest('POST', '/api/contact', data);
}

export async function subscribeToNewsletter(email: string) {
  return apiRequest('POST', '/api/subscribe', { email });
}
