import { useQuery } from "@tanstack/react-query";
import { Link } from "wouter";
import { Skeleton } from "@/components/ui/skeleton";
import { Store, ChevronLeft } from "@/lib/icons";
import { type AffiliateProduct } from "@/lib/types";

const AffiliatePage = () => {
  const { data: affiliateProducts, isLoading } = useQuery<AffiliateProduct[]>({
    queryKey: ['/api/affiliate-products'],
  });

  return (
    <div className="bg-gray-50 py-12">
      <div className="container mx-auto px-4 sm:px-6 lg:px-8">
        <div className="mb-8">
          <Link href="/" className="inline-flex items-center text-primary-600 hover:text-primary-700 mb-4">
            <ChevronLeft className="h-5 w-5 mr-1" /> Retour à l'accueil
          </Link>
          
          <h1 className="text-3xl md:text-4xl font-bold font-montserrat text-gray-900 mb-4">
            Produits Partenaires
          </h1>
          <p className="text-lg text-gray-600 max-w-3xl">
            Découvrez notre sélection de produits partenaires soigneusement choisis pour compléter votre
            expérience de lecture et améliorer votre productivité.
          </p>
        </div>

        {isLoading ? (
          <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-8">
            {[...Array(6)].map((_, index) => (
              <div key={index} className="bg-white rounded-xl shadow-md overflow-hidden">
                <Skeleton className="h-60 w-full" />
                <div className="p-6">
                  <Skeleton className="h-6 w-3/4 mb-2" />
                  <Skeleton className="h-4 w-full mb-4" />
                  <div className="flex justify-between items-center mb-4">
                    <Skeleton className="h-5 w-16" />
                    <Skeleton className="h-4 w-24" />
                  </div>
                  <Skeleton className="h-12 w-full" />
                </div>
              </div>
            ))}
          </div>
        ) : affiliateProducts && affiliateProducts.length > 0 ? (
          <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-8">
            {affiliateProducts.map((product) => (
              <div 
                key={product.id} 
                className="bg-white rounded-xl shadow-md overflow-hidden transition-all hover:shadow-lg hover:scale-105"
              >
                <div className="relative">
                  <img 
                    src={product.imageUrl} 
                    alt={product.title} 
                    className="w-full h-60 object-cover" 
                  />
                  <div className="absolute top-3 right-3 bg-teal-500 text-white text-sm font-medium py-1 px-2 rounded">
                    Partenaire
                  </div>
                </div>
                <div className="p-6">
                  <h3 className="text-xl font-bold font-montserrat text-gray-900 mb-1">{product.title}</h3>
                  <p className="text-gray-500 mb-4">{product.description}</p>
                  <div className="flex justify-between items-center mb-4">
                    <span className="text-[#f97316] font-bold text-lg">{product.price.toFixed(2)} €</span>
                    <div className="flex items-center text-gray-600">
                      <Store className="mr-1 h-4 w-4" /> {product.storeName}
                    </div>
                  </div>
                  <a 
                    href={product.storeUrl} 
                    target="_blank" 
                    rel="noopener noreferrer" 
                    className="block w-full bg-teal-500 hover:bg-teal-600 text-white text-center font-medium py-3 px-4 rounded-lg transition"
                  >
                    Voir l'offre
                  </a>
                </div>
              </div>
            ))}
          </div>
        ) : (
          <div className="text-center py-16 bg-white rounded-lg shadow-sm">
            <h3 className="text-xl font-medium text-gray-700 mb-2">Aucun produit partenaire disponible</h3>
            <p className="text-gray-600 mb-4">
              Nous travaillons à l'ajout de nouveaux produits partenaires. Revenez bientôt !
            </p>
            <Link href="/" className="text-primary-600 hover:text-primary-700 font-medium">
              Retourner à l'accueil
            </Link>
          </div>
        )}
      </div>
    </div>
  );
};

export default AffiliatePage;
