import { useQuery } from "@tanstack/react-query";
import { Button } from "@/components/ui/button";
import { Card, CardContent } from "@/components/ui/card";
import { Skeleton } from "@/components/ui/skeleton";
import { fetchAffiliateProducts } from "@/lib/data";
import { trackAffiliateClick } from "@/lib/utils";
import Newsletter from "@/components/home/Newsletter";

const Affiliates = () => {
  const { data: products = [], isLoading } = useQuery({
    queryKey: ['/api/affiliate-products'],
    queryFn: fetchAffiliateProducts,
  });

  return (
    <>
      <section className="py-12 bg-primary text-white">
        <div className="container mx-auto px-4 text-center">
          <h1 className="text-3xl md:text-4xl font-bold mb-4">
            Produits d'affiliation recommandés
          </h1>
          <p className="text-lg max-w-2xl mx-auto">
            Découvrez notre sélection de produits et services partenaires qui complètent parfaitement nos eBooks et vous aideront à atteindre vos objectifs.
          </p>
        </div>
      </section>
      
      <section className="py-12 bg-white">
        <div className="container mx-auto px-4">
          <div className="mb-8">
            <h2 className="text-2xl font-bold mb-4">Nos recommandations</h2>
            <p className="text-gray-600">
              Tous les produits ci-dessous ont été soigneusement sélectionnés pour leur qualité et leur pertinence.
            </p>
          </div>
          
          <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-8">
            {isLoading ? (
              Array(6).fill(0).map((_, i) => (
                <Card key={i} className="overflow-hidden">
                  <div className="relative h-60">
                    <Skeleton className="w-full h-full" />
                  </div>
                  <CardContent className="p-6">
                    <Skeleton className="h-4 w-16 mb-2" />
                    <Skeleton className="h-6 w-full mb-3" />
                    <Skeleton className="h-4 w-full mb-2" />
                    <Skeleton className="h-4 w-full mb-2" />
                    <Skeleton className="h-4 w-3/4 mb-6" />
                    <div className="flex justify-between items-center">
                      <Skeleton className="h-6 w-24" />
                      <Skeleton className="h-10 w-32" />
                    </div>
                  </CardContent>
                </Card>
              ))
            ) : (
              products.map((product) => (
                <Card key={product.id} className="bg-white rounded-lg shadow-md overflow-hidden hover:shadow-lg transition-shadow duration-300">
                  <div className="relative h-60">
                    <img 
                      src={product.imageUrl}
                      alt={product.title}
                      className="w-full h-full object-cover"
                    />
                    <div className="absolute top-0 right-0 bg-[#F59E0B] text-white text-xs px-2 py-1 m-2 rounded">
                      Partenaire
                    </div>
                  </div>
                  <CardContent className="p-6">
                    <div className="text-xs text-gray-500 mb-2 uppercase tracking-wider">
                      {product.category}
                    </div>
                    <h3 className="font-semibold text-xl mb-3">
                      {product.title}
                    </h3>
                    <p className="text-gray-600 mb-6">
                      {product.description}
                    </p>
                    <div className="flex justify-between items-center">
                      <div>
                        {product.originalPrice && (
                          <span className="line-through text-gray-400">{product.originalPrice}</span>
                        )}
                        <span className={`font-bold text-lg text-primary ${product.originalPrice ? 'ml-2' : ''}`}>
                          {product.price}
                        </span>
                      </div>
                      <Button 
                        className="bg-[#F59E0B] text-white hover:bg-[#F59E0B]/90 transition-colors duration-200"
                        onClick={() => trackAffiliateClick(product.externalUrl)}
                      >
                        En savoir plus
                      </Button>
                    </div>
                  </CardContent>
                </Card>
              ))
            )}
          </div>
          
          <div className="mt-12 bg-gray-50 p-8 rounded-lg">
            <h3 className="text-xl font-semibold mb-4">Information importante</h3>
            <p className="text-gray-600">
              En tant qu'affilié, nous pouvons recevoir une commission sur les achats effectués via les liens ci-dessus, sans frais supplémentaires pour vous. Nous ne recommandons que des produits en lesquels nous croyons et que nous utilisons nous-mêmes.
            </p>
          </div>
        </div>
      </section>
      
      <Newsletter />
    </>
  );
};

export default Affiliates;
