import { Link } from "wouter";
import { useCart } from "@/hooks/use-cart";
import { Button } from "@/components/ui/button";
import { Trash2, Plus, Minus } from "lucide-react";

const CartPage = () => {
  const { items, removeItem, updateQuantity, totalItems, totalPrice } = useCart();

  if (items.length === 0) {
    return (
      <div className="container mx-auto px-4 py-16">
        <h1 className="text-3xl font-bold mb-8 text-center">Votre Panier</h1>
        <div className="bg-white rounded-lg shadow-lg p-8 text-center max-w-2xl mx-auto">
          <p className="text-xl mb-6">Votre panier est vide</p>
          <Button asChild className="bg-[#ff9633] hover:bg-[#f97316] text-white">
            <Link href="/">Continuer mes achats</Link>
          </Button>
        </div>
      </div>
    );
  }

  return (
    <div className="container mx-auto px-4 py-16">
      <h1 className="text-3xl font-bold mb-8">Votre Panier ({totalItems} {totalItems > 1 ? 'articles' : 'article'})</h1>
      
      <div className="grid md:grid-cols-3 gap-8">
        <div className="md:col-span-2">
          <div className="bg-white rounded-lg shadow-lg overflow-hidden">
            <div className="p-6">
              <table className="w-full">
                <thead className="border-b">
                  <tr>
                    <th className="text-left font-semibold py-3">Produit</th>
                    <th className="text-center font-semibold py-3">Quantité</th>
                    <th className="text-right font-semibold py-3">Prix</th>
                    <th className="text-right font-semibold py-3">Actions</th>
                  </tr>
                </thead>
                <tbody>
                  {items.map((item) => (
                    <tr key={item.product.id} className="border-b">
                      <td className="py-4">
                        <div className="flex items-center">
                          <img 
                            src={item.product.imageUrl} 
                            alt={item.product.title}
                            className="w-16 h-20 object-cover rounded mr-4"
                          />
                          <div>
                            <h3 className="font-semibold">{item.product.title}</h3>
                            <p className="text-sm text-gray-600">eBook</p>
                          </div>
                        </div>
                      </td>
                      <td className="py-4">
                        <div className="flex items-center justify-center">
                          <Button 
                            variant="outline" 
                            size="icon" 
                            className="h-8 w-8"
                            onClick={() => updateQuantity(item.product.id, Math.max(1, item.quantity - 1))}
                          >
                            <Minus className="h-4 w-4" />
                          </Button>
                          <span className="mx-2 font-medium">{item.quantity}</span>
                          <Button 
                            variant="outline" 
                            size="icon" 
                            className="h-8 w-8"
                            onClick={() => updateQuantity(item.product.id, item.quantity + 1)}
                          >
                            <Plus className="h-4 w-4" />
                          </Button>
                        </div>
                      </td>
                      <td className="py-4 text-right font-medium">
                        {(item.product.price * item.quantity).toFixed(2)} €
                      </td>
                      <td className="py-4 text-right">
                        <Button 
                          variant="ghost" 
                          size="icon"
                          onClick={() => removeItem(item.product.id)}
                          className="text-red-500 hover:text-red-700 hover:bg-red-100"
                        >
                          <Trash2 className="h-5 w-5" />
                        </Button>
                      </td>
                    </tr>
                  ))}
                </tbody>
              </table>
            </div>
          </div>
        </div>
        
        <div className="md:col-span-1">
          <div className="bg-white rounded-lg shadow-lg p-6">
            <h2 className="text-xl font-bold mb-4">Récapitulatif de la commande</h2>
            <div className="space-y-3">
              <div className="flex justify-between border-b pb-3">
                <span>Sous-total</span>
                <span>{totalPrice.toFixed(2)} €</span>
              </div>
              <div className="flex justify-between border-b pb-3">
                <span>TVA (20%)</span>
                <span>{(totalPrice * 0.2).toFixed(2)} €</span>
              </div>
              <div className="flex justify-between text-lg font-bold pt-1">
                <span>Total</span>
                <span>{(totalPrice * 1.2).toFixed(2)} €</span>
              </div>
            </div>
            
            <div className="mt-6 space-y-3">
              <Button 
                asChild
                className="w-full bg-[#ff9633] hover:bg-[#f97316] text-white font-medium"
              >
                <Link href="/checkout">
                  Procéder au paiement
                </Link>
              </Button>
              <Button 
                asChild
                variant="outline" 
                className="w-full"
              >
                <Link href="/">
                  Continuer mes achats
                </Link>
              </Button>
            </div>
          </div>
        </div>
      </div>
    </div>
  );
};

export default CartPage;