import { useParams } from "wouter";
import { useQuery } from "@tanstack/react-query";
import { Button } from "@/components/ui/button";
import { Skeleton } from "@/components/ui/skeleton";
import { fetchProduct } from "@/lib/data";
import { formatPrice } from "@/lib/utils";
import Newsletter from "@/components/home/Newsletter";

const ProductDetail = () => {
  const { id } = useParams<{ id: string }>();
  const productId = parseInt(id);
  
  const { data: product, isLoading, isError } = useQuery({
    queryKey: ['/api/products', productId],
    queryFn: () => fetchProduct(productId),
    enabled: !isNaN(productId),
  });

  if (isLoading) {
    return (
      <div className="py-12 bg-white">
        <div className="container mx-auto px-4">
          <div className="flex flex-col md:flex-row gap-12">
            <div className="w-full md:w-1/2">
              <Skeleton className="w-full aspect-[3/4] rounded-lg" />
            </div>
            
            <div className="w-full md:w-1/2">
              <Skeleton className="h-8 w-3/4 mb-2" />
              <Skeleton className="h-4 w-1/4 mb-6" />
              
              <Skeleton className="h-4 w-full mb-2" />
              <Skeleton className="h-4 w-full mb-2" />
              <Skeleton className="h-4 w-full mb-2" />
              <Skeleton className="h-4 w-3/4 mb-8" />
              
              <Skeleton className="h-8 w-1/3 mb-6" />
              
              <div className="flex gap-4">
                <Skeleton className="h-10 w-36" />
                <Skeleton className="h-10 w-36" />
              </div>
            </div>
          </div>
        </div>
      </div>
    );
  }

  if (isError || !product) {
    return (
      <div className="py-12 bg-white">
        <div className="container mx-auto px-4 text-center">
          <h2 className="text-2xl font-bold mb-4">Produit non trouvé</h2>
          <p className="text-gray-600 mb-6">
            Désolé, nous n'avons pas pu trouver le produit que vous recherchez.
          </p>
          <Button className="bg-primary text-white hover:bg-primary/90" asChild>
            <a href="/">Retour à l'accueil</a>
          </Button>
        </div>
      </div>
    );
  }

  return (
    <>
      <div className="py-12 bg-white">
        <div className="container mx-auto px-4">
          <div className="flex flex-col md:flex-row gap-12">
            <div className="w-full md:w-1/2">
              <div className="relative rounded-lg overflow-hidden shadow-lg">
                <img 
                  src={product.imageUrl}
                  alt={product.title}
                  className="w-full object-cover"
                />
                {product.isBestseller && (
                  <div className="absolute top-4 right-4 bg-[#F59E0B] text-white text-sm px-3 py-1 rounded">
                    Bestseller
                  </div>
                )}
                {product.isNew && (
                  <div className="absolute top-4 right-4 bg-[#C026D3] text-white text-sm px-3 py-1 rounded">
                    Nouveau
                  </div>
                )}
              </div>
            </div>
            
            <div className="w-full md:w-1/2">
              <h1 className="text-3xl font-bold mb-2">{product.title}</h1>
              <div className="text-gray-600 mb-6">Catégorie: {product.category}</div>
              
              <div className="prose mb-8">
                <p>{product.description}</p>
              </div>
              
              <div className="text-3xl font-bold text-primary mb-6">
                {formatPrice(product.price)}
              </div>
              
              <div className="flex flex-col sm:flex-row gap-4">
                <Button className="bg-primary text-white hover:bg-primary/90 px-8">
                  Ajouter au panier
                </Button>
                <Button variant="outline" className="border-primary text-primary hover:bg-primary/10">
                  Ajouter à la liste de souhaits
                </Button>
              </div>
              
              <div className="mt-8 border-t pt-6">
                <h3 className="font-semibold mb-2">Détails du produit:</h3>
                <ul className="space-y-2 text-gray-600">
                  <li>Format: eBook (PDF, EPUB, MOBI)</li>
                  <li>Pages: Environ 200</li>
                  <li>Langue: Français</li>
                  <li>Téléchargement immédiat après achat</li>
                </ul>
              </div>
            </div>
          </div>
        </div>
      </div>
      <Newsletter />
    </>
  );
};

export default ProductDetail;
